@@ -15,9 +15,12 @@ def main():
 
 
 @main.command()
-def init():
+@click.option('--debug', is_flag=True, default=False, help="Enable debug output")
+def init(debug):
     """Initialize LinkP configuration files."""
     try:
+        if debug:
+            click.echo("Debug mode enabled for init.")
         init_config()
         click.echo("\n✅ LinkP initialized successfully!")
         click.echo("\nNext steps:")
@@ -25,17 +28,26 @@ def init():
         click.echo("2. Run 'linkp run' to post your first update")
     except Exception as e:
         click.echo(f"❌ Error: {e}", err=True)
+        if debug:
+            import traceback
+            traceback.print_exc()
         sys.exit(1)
 
 
 @main.command()
-def run():
+@click.option('--debug', is_flag=True, default=False, help="Enable debug output")
+def run(debug):
     """Run daily LinkedIn post generation and posting."""
     try:
-        run_daily_post()
+        if debug:
+            click.echo("Debug mode enabled for run.")
+        run_daily_post(debug=debug)
         click.echo("\n✅ LinkedIn post created and posted successfully!")
     except Exception as e:
         click.echo(f"❌ Error: {e}", err=True)
+        if debug:
+            import traceback
+            traceback.print_exc()
         sys.exit(1)
 
 
